==> monica-3.7.0p2.tgz: www/monica/resources/lang/cs/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'Připomínka pro :contact',
    'greetings' => 'Ahoj :username',
    'want_reminded_of' => 'You wanted to be reminded of :reason',
    'for' => 'For: :name',
    'comment' => 'Comment: :comment',
    'footer_contact_info' => 'Přidat, zobrazit, dodat a změnit informace k této osobě:',
    'footer_contact_info2' => 'See :name’s profile',
    'footer_contact_info2_link' => 'See :name’s profile: :url',

    'notification_subject_line' => 'You have an upcoming event',
    'notification_description' => 'In :count days (on :date), the following event will happen:',

    'stay_in_touch_subject_line' => 'Stay in touch with :name',
    'stay_in_touch_subject_description' => 'You asked to be reminded to stay in touch with :name every :frequency day.|You asked to be reminded to stay in touch with :name every :frequency days.',

    'notifications_whoops' => 'Whoops!',
    'notifications_hello' => 'Hello!',
    'notifications_regards' => 'Regards',
    'notifications_footer' => 'If you’re having trouble clicking the ":actionText" button, copy and paste the URL below into your web browser: [:actionURL](:actionURL)',
    'notifications_rights' => 'All rights reserved',

    'confirmation_email_title' => 'Monica – Email verification',
    'confirmation_email_intro'=> 'To validate your email click on the button below',
    'confirmation_email_button' => 'Verify email address',
    'confirmation_email_bottom' => 'If you did not create an account, no further action is required.',

    'password_reset_title' => 'Monica – Reset Password Notification',
    'password_reset_intro' => 'You are receiving this email because we received a password reset request for your account.',
    'password_reset_button' => 'Reset Password',
    'password_reset_expiration' => 'This password reset link will expire in :count minutes.',
    'password_reset_bottom' => 'If you did not request a password reset, no further action is required.',

    'invitation_title' => 'Monica – You are invited by :name',
    'invitation_intro' => 'You’ve been invited by :name (:email) to use Monica, a nice Personal Relationship Management tool.',
    'invitation_link' => 'To accept the invitation, click on the link below:',
    'invitation_button' => 'Accept invitation',
    'invitation_expiration' => 'This link will expire in :count days.',

    'export_title' => 'Váš export je připraven',
    'export_description' => 'Žádali jste o export dat dne :date. Nyní je připraven ke stažení.',
    'export_download' => 'Stáhnout export',

];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/cs/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'Připomínka pro :contact',
    'greetings' => 'Ahoj :username',
    'want_reminded_of' => 'You wanted to be reminded of :reason',
    'for' => 'For: :name',
    'comment' => 'Comment: :comment',
    'footer_contact_info' => 'Přidat, zobrazit, dodat a změnit informace k této osobě:',
    'footer_contact_info2' => 'See :name’s profile',
    'footer_contact_info2_link' => 'See :name’s profile: :url',

    'notification_subject_line' => 'You have an upcoming event',
    'notification_description' => 'In :count days (on :date), the following event will happen:',

    'stay_in_touch_subject_line' => 'Stay in touch with :name',
    'stay_in_touch_subject_description' => 'You asked to be reminded to stay in touch with :name every :frequency day.|You asked to be reminded to stay in touch with :name every :frequency days.',

    'notifications_whoops' => 'Whoops!',
    'notifications_hello' => 'Hello!',
    'notifications_regards' => 'Regards',
    'notifications_footer' => 'If you’re having trouble clicking the ":actionText" button, copy and paste the URL below into your web browser: [:actionURL](:actionURL)',
    'notifications_rights' => 'Všechna práva vyhrazena',

    'confirmation_email_title' => 'Monica – ověření e-mailu',
    'confirmation_email_intro'=> 'Pro ověření svého e-mailu klikněte na tlačítko níže',
    'confirmation_email_button' => 'Ověřit e-mailovou adresu',
    'confirmation_email_bottom' => 'Pokud jste si nevytvořili účet sami, není vyžadována žádná další akce.',

    'password_reset_title' => 'Monica – oznámení o obnovení hesla',
    'password_reset_intro' => 'Tento e-mail jste obdrželi, protože jsme dostali žádost o obnovení hesla k Vašemu účtu.',
    'password_reset_button' => 'Resetovat heslo',
    'password_reset_expiration' => 'Tento odkaz pro obnovení hesla vyprší za :count minut.',
    'password_reset_bottom' => 'If you did not request a password reset, no further action is required.',

    'invitation_title' => 'Monica – You are invited by :name',
    'invitation_intro' => 'You’ve been invited by :name (:email) to use Monica, a nice Personal Relationship Management tool.',
    'invitation_link' => 'To accept the invitation, click on the link below:',
    'invitation_button' => 'Accept invitation',
    'invitation_expiration' => 'This link will expire in :count days.',

    'export_title' => 'Váš export je připraven',
    'export_description' => 'Žádali jste o export dat dne :date. Nyní je připraven ke stažení.',
    'export_download' => 'Stáhnout export',

];
